aboutsummaryrefslogtreecommitdiffstats
path: root/packages/meshbay-hub/src/meshbay_hub/static/photos-app.js
diff options
context:
space:
mode:
Diffstat (limited to 'packages/meshbay-hub/src/meshbay_hub/static/photos-app.js')
-rw-r--r--packages/meshbay-hub/src/meshbay_hub/static/photos-app.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/packages/meshbay-hub/src/meshbay_hub/static/photos-app.js b/packages/meshbay-hub/src/meshbay_hub/static/photos-app.js
index 261f2af..73b8c15 100644
--- a/packages/meshbay-hub/src/meshbay_hub/static/photos-app.js
+++ b/packages/meshbay-hub/src/meshbay_hub/static/photos-app.js
@@ -7,7 +7,7 @@ import {
formatSize, CHUNK_SIZE, pipelinedDownload, downloadDirectory,
} from './file-utils.js';
import { transfers } from './transfers.js';
-import { MediaThumb, LazyTile } from './video-app.js';
+import { MediaThumb, LazyTile } from './media-tiles.js';
import { SourceTag } from './group-name.js';
// ── Photos ───────────────────────────────────────────────────────────────────
@@ -129,7 +129,7 @@ function PhotoTile({ entry, transportRef, gekRef, onOpen }) {
// ── lightbox: full image, next/previous, per-photo info, zoom ──────────────
//
// Cached per session by file id, same shape as video-app.js's
// _thumbBlobCache — clicking back and forth between two photos decrypts
// each once, not once per visit.
const _fullBlobCache = new Map();
@@ -129,7 +129,7 @@ function PhotoTile({ entry, transportRef, gekRef, onOpen }) {
// ── lightbox: full image, next/previous, per-photo info, zoom ──────────────
//
-// Cached per session by file id, same shape as video-app.js's
+// Cached per session by file id, same shape as media-tiles.js's
// _thumbBlobCache — clicking back and forth between two photos decrypts
// each once, not once per visit.